Biblicus Documentation
======================

Corpus management and retrieval evaluation in Python.

Contents
--------

.. toctree::
   :maxdepth: 2

   CORPUS
   EXTRACTION
   extractors/index
   KNOWLEDGE_BASE
   BACKENDS
   backends/index
   RETRIEVAL
   RETRIEVAL_QUALITY
   RETRIEVAL_EVALUATION
   CONTEXT_PACK
   ANALYSIS
   PROFILING
   TOPIC_MODELING
   DEMOS
   USER_CONFIGURATION
   TESTING
   FEATURE_INDEX
   ROADMAP
   ARCHITECTURE
   CORPUS_DESIGN
   api
